@@ -16,14 +16,15 @@ from octavia_lib.common import constants
 # TODO(mjozefcz): Use those variables from neutron-lib once released.
 LRP_PREFIX = "lrp-"
 OVN_NAME_PREFIX = "neutron-"
+LB_HM_PORT_PREFIX = "ovn-lb-hm-"
 LB_VIP_PORT_PREFIX = "ovn-lb-vip-"
 OVN_PORT_NAME_EXT_ID_KEY = 'neutron:port_name'
 OVN_ROUTER_NAME_EXT_ID_KEY = 'neutron:router_name'
-OVN_PORT_NAME_EXT_ID_KEY = 'neutron:port_name'
 OVN_PORT_FIP_EXT_ID_KEY = 'neutron:port_fip'
 OVN_SUBNET_EXT_ID_KEY = 'neutron:subnet_id'
 OVN_SUBNET_EXT_IDS_KEY = 'neutron:subnet_ids'
 OVN_NETWORK_NAME_EXT_ID_KEY = 'neutron:network_name'
+OVN_PROJECT_EXT_ID_KEY = 'neutron:project_id'
 OVN_SG_IDS_EXT_ID_KEY = 'neutron:security_group_ids'
 OVN_DEVICE_OWNER_EXT_ID_KEY = 'neutron:device_owner'
 OVN_FIP_EXT_ID_KEY = 'neutron:fip_id'
@@ -32,12 +33,18 @@ OVN_GW_PORT_EXT_ID_KEY = 'neutron:gw_port_id'
 OVN_PORT_CIDR_EXT_ID_KEY = 'neutron:cidrs'
 OVN_MEMBER_STATUS_KEY = 'neutron:member_status'
 
+# TODO(froyo): Use from neutron-lib once released.
+OVN_LB_HM_PORT_DISTRIBUTED = 'ovn-lb-hm:distributed'
+
 LB_EXT_IDS_LS_REFS_KEY = 'ls_refs'
 LB_EXT_IDS_LR_REF_KEY = 'lr_ref'
 LB_EXT_IDS_POOL_PREFIX = 'pool_'
 LB_EXT_IDS_LISTENER_PREFIX = 'listener_'
 LB_EXT_IDS_MEMBER_PREFIX = 'member_'
 LB_EXT_IDS_HM_KEY = 'octavia:healthmonitor'
+LB_EXT_IDS_HM_POOL_KEY = 'octavia:pool_id'
+LB_EXT_IDS_HM_VIP = 'octavia:vip'
+LB_EXT_IDS_HMS_KEY = 'octavia:healthmonitors'
 LB_EXT_IDS_VIP_KEY = 'neutron:vip'
 LB_EXT_IDS_VIP_FIP_KEY = 'neutron:vip_fip'
 LB_EXT_IDS_VIP_PORT_ID_KEY = 'neutron:vip_port_id'
@@ -107,3 +114,6 @@ LB_SELECTION_FIELDS_MAP = {
 # HM events status
 HM_EVENT_MEMBER_PORT_ONLINE = ['online']
 HM_EVENT_MEMBER_PORT_OFFLINE = ['offline']
+
+# max timeout for request
+MAX_TIMEOUT_REQUEST = 5
