@@ -15,6 +15,7 @@ import contextlib
 
 import netaddr
 
+from neutron_lib import constants as n_const
 from neutron_lib import exceptions as n_exc
 from oslo_log import log
 from ovsdbapp.backend import ovs_idl
@@ -31,7 +32,6 @@ from ovn_octavia_provider.common import config
 from ovn_octavia_provider.common import exceptions as ovn_exc
 from ovn_octavia_provider.common import utils
 from ovn_octavia_provider.i18n import _
-from ovn_octavia_provider.ovsdb import impl_idl_ovn
 from ovn_octavia_provider.ovsdb import ovsdb_monitor
 
 
@@ -52,34 +52,7 @@ class OvnNbTransaction(idl_trans.Transaction):
         self.api.nb_global.increment('nb_cfg')
 
 
-# This version of Backend doesn't use a class variable for ovsdb_connection
-# and therefor allows networking-ovn to manage connection scope on its own
 class Backend(ovs_idl.Backend):
-    lookup_table = {}
-    ovsdb_connection = None
-
-    def __init__(self, connection):
-        self.ovsdb_connection = connection
-        super().__init__(connection)
-
-    def start_connection(self, connection):
-        try:
-            self.ovsdb_connection.start()
-        except Exception as e:
-            connection_exception = OvsdbConnectionUnavailable(
-                db_schema=self.schema, error=e)
-            LOG.exception(connection_exception)
-            raise connection_exception from e
-
-    @property
-    def idl(self):
-        return self.ovsdb_connection.idl
-
-    @property
-    def tables(self):
-        return self.idl.tables
-
-    _tables = tables
 
     def is_table_present(self, table_name):
         return table_name in self._tables
@@ -88,11 +61,6 @@ class Backend(ovs_idl.Backend):
         return self.is_table_present(table_name) and (
             col_name in self._tables[table_name].columns)
 
-    def create_transaction(self, check_error=False, log_errors=True):
-        return idl_trans.Transaction(
-            self, self.ovsdb_connection, self.ovsdb_connection.timeout,
-            check_error, log_errors)
-
     # Check for a column match in the table. If not found do a retry with
     # a stop delay of 10 secs. This function would be useful if the caller
     # wants to verify for the presence of a particular row in the table
@@ -139,33 +107,51 @@ class GetLrsCommand(command.ReadOnlyCommand):
             self.api.tables['Logical_Router'].rows.values()]
 
 
-class LbAddIpPortMappingCommand(command.BaseCommand):
+# NOTE(froyo): remove this class once ovsdbapp manages the IPv6 into [ ]
+# https://bugs.launchpad.net/ovsdbapp/+bug/2057471
+class DelBackendFromIPPortMapping(command.BaseCommand):
     table = 'Load_Balancer'
 
-    def __init__(self, api, lb, endpoint_ip, port_name, source_ip):
+    def __init__(self, api, lb, backend_ip):
         super().__init__(api)
         self.lb = lb
-        self.endpoint_ip = str(netaddr.IPAddress(endpoint_ip))
+        if netaddr.IPNetwork(backend_ip).version == n_const.IP_VERSION_6:
+            self.backend_ip = f'[{backend_ip}]'
+        else:
+            self.backend_ip = backend_ip
+
+    def run_idl(self, txn):
+        try:
+            ovn_lb = self.api.lookup(self.table, self.lb)
+            ovn_lb.delkey('ip_port_mappings', self.backend_ip)
+        except Exception:
+            LOG.exception("Error deleting backend %s from ip_port_mappings "
+                          "for LB uuid %s", str(self.backend_ip), str(self.lb))
+
+
+# NOTE(froyo): remove this class once ovsdbapp manages the IPv6 into [ ]
+# https://bugs.launchpad.net/ovsdbapp/+bug/2057471
+class AddBackendToIPPortMapping(command.BaseCommand):
+    table = 'Load_Balancer'
+
+    def __init__(self, api, lb, backend_ip, port_name, src_ip):
+        super().__init__(api)
+        self.lb = lb
+        self.backend_ip = backend_ip
         self.port_name = port_name
-        self.source_ip = str(netaddr.IPAddress(source_ip))
+        self.src_ip = src_ip
+        if netaddr.IPNetwork(backend_ip).version == n_const.IP_VERSION_6:
+            self.backend_ip = f'[{backend_ip}]'
+            self.src_ip = f'[{src_ip}]'
 
     def run_idl(self, txn):
-        lb = self.api.lookup(self.table, self.lb)
-        lb.setkey('ip_port_mappings', self.endpoint_ip,
-                  '%s:%s' % (self.port_name, self.source_ip))
-
-
-class LbDelIpPortMappingCommand(command.BaseCommand):
-    table = 'Load_Balancer'
-
-    def __init__(self, api, lb, endpoint_ip):
-        super().__init__(api)
-        self.lb = lb
-        self.endpoint_ip = str(netaddr.IPAddress(endpoint_ip))
-
-    def run_idl(self, txn):
-        lb = self.api.lookup(self.table, self.lb)
-        lb.delkey('ip_port_mappings', self.endpoint_ip)
+        try:
+            lb = self.api.lookup(self.table, self.lb)
+            lb.setkey('ip_port_mappings', self.backend_ip,
+                      '%s:%s' % (self.port_name, self.src_ip))
+        except Exception:
+            LOG.exception("Error adding backend %s to ip_port_mappings "
+                          "for LB uuid %s", str(self.backend_ip), str(self.lb))
 
 
 class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
@@ -203,20 +189,14 @@ class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
     def get_lrs(self):
         return GetLrsCommand(self)
 
-    # FIXME (froyo): Remove this method once the ovsdbapp version is upgraded
-    # to a version higher than 2.1.0, it will be possible to remove this method
-    # This is done due to some conflict on bumping the noted version. Also
-    # class LbDelIpPortMappingCommand shall be removed at the same time.
-    def lb_del_ip_port_mapping(self, lb, endpoint_ip):
-        return LbDelIpPortMappingCommand(self, lb, endpoint_ip)
+    # NOTE(froyo): remove this method once ovsdbapp manages the IPv6 into [ ]
+    def lb_del_ip_port_mapping(self, lb_uuid, backend_ip):
+        return DelBackendFromIPPortMapping(self, lb_uuid, backend_ip)
 
-    # FIXME (froyo): Remove this method once the ovsdbapp version is upgraded
-    # to a version higher than 2.1.0, it will be possible to remove this method
-    # This is done due to some conflict on bumping the noted version. Also
-    # class LbAddIpPortMappingCommand shall be removed at the same time.
-    def lb_add_ip_port_mapping(self, lb, endpoint_ip, port_name, source_ip):
-        return LbAddIpPortMappingCommand(self, lb, endpoint_ip, port_name,
-                                         source_ip)
+    # NOTE(froyo): remove this method once ovsdbapp manages the IPv6 into [ ]
+    def lb_add_ip_port_mapping(self, lb_uuid, backend_ip, port_name, src_ip):
+        return AddBackendToIPPortMapping(self, lb_uuid, backend_ip, port_name,
+                                         src_ip)
 
 
 class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
@@ -232,40 +212,23 @@ class OvnNbIdlForLb(ovsdb_monitor.OvnIdl):
               'Logical_Router', 'Logical_Switch_Port', 'Logical_Router_Port',
               'Gateway_Chassis', 'NAT')
 
-    def __init__(self, event_lock_name=None):
+    def __init__(self, event_lock_name=None, notifier=True):
         self.conn_string = config.get_ovn_nb_connection()
         ovsdb_monitor._check_and_set_ssl_files(self.SCHEMA)
         helper = self._get_ovsdb_helper(self.conn_string)
         for table in OvnNbIdlForLb.TABLES:
             helper.register_table(table)
         super().__init__(
-            driver=None, remote=self.conn_string, schema=helper)
+            driver=None, remote=self.conn_string, schema=helper,
+            notifier=notifier)
         self.event_lock_name = event_lock_name
         if self.event_lock_name:
             self.set_lock(self.event_lock_name)
-        atexit.register(self.stop)
 
     @utils.retry()
     def _get_ovsdb_helper(self, connection_string):
         return idlutils.get_schema_helper(connection_string, self.SCHEMA)
 
-    def start(self):
-        self.conn = connection.Connection(
-            self, timeout=config.get_ovn_ovsdb_timeout())
-        return impl_idl_ovn.OvsdbNbOvnIdl(self.conn)
-
-    def stop(self):
-        # Close the running connection if it has been initalized
-        if hasattr(self, 'conn'):
-            if not self.conn.stop(timeout=config.get_ovn_ovsdb_timeout()):
-                LOG.debug("Connection terminated to OvnNb "
-                          "but a thread is still alive")
-            del self.conn
-        # complete the shutdown for the event handler
-        self.notify_handler.shutdown()
-        # Close the idl session
-        self.close()
-
 
 class OvnSbIdlForLb(ovsdb_monitor.OvnIdl):
     SCHEMA = "OVN_Southbound"
@@ -291,7 +254,7 @@ class OvnSbIdlForLb(ovsdb_monitor.OvnIdl):
     def start(self):
         self.conn = connection.Connection(
             self, timeout=config.get_ovn_ovsdb_timeout())
-        return impl_idl_ovn.OvsdbSbOvnIdl(self.conn)
+        return OvsdbSbOvnIdl(self.conn)
 
     def stop(self):
         # Close the running connection if it has been initalized
